@@ -1,7 +1,10 @@
-from __future__ import absolute_import
-import sqlalchemy, sqlalchemy.engine, sqlalchemy.event
-from . import parallel_tasks as pt
+import sqlalchemy
+import sqlalchemy.engine
+import sqlalchemy.event
+
 from . import core
+from . import parallel_tasks as pt
+
 global rlock
 
 __author__ = 'app'
@@ -22,4 +25,4 @@ def make_engine_blocking(engine=None):
 
     sqlalchemy.event.listen(engine, 'begin', event_begin )
     sqlalchemy.event.listen(engine, 'commit', event_commit_or_rollback)
-    sqlalchemy.event.listen(engine, 'rollback', event_commit_or_rollback)
\ No newline at end of file
+    sqlalchemy.event.listen(engine, 'rollback', event_commit_or_rollback)
