@@ -1,28 +1,25 @@
-from __future__ import absolute_import
-
 import glob
 import os
 import os.path
 import time
 import weakref
-import numpy as np
+from collections import defaultdict
 from itertools import chain
+
+import numpy as np
 from more_itertools import always_iterable
+
 from ..util import proxy_object
 
 pynbody = None # deferred import; occurs when a PynbodyInputHandler is constructed
 
-from . import finding
-from . import HandlerBase
 from .. import config
 from ..log import logger
-from six.moves import range
-
-
+from . import HandlerBase, finding
 
 _loaded_halocats = {}
 
-class DummyTimeStep(object):
+class DummyTimeStep:
     def __init__(self, filename):
         self.filename = filename
 
@@ -45,7 +42,7 @@ class PynbodyInputHandler(finding.PatternBasedFileDiscovery, HandlerBase):
         return object.__new__(cls)
 
     def __init__(self, *args, **kwargs):
-        super(PynbodyInputHandler, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
 
         # old versions of pynbody have no __version__!
@@ -65,12 +62,12 @@ class PynbodyInputHandler(finding.PatternBasedFileDiscovery, HandlerBase):
         try:
             f = pynbody.load(filepath)
             if self.quicker:
-                logger.warn("Pynbody was able to load %r, but because 'quicker' flag is set we won't check whether it can also load the halo files", filepath)
+                logger.warning("Pynbody was able to load %r, but because 'quicker' flag is set we won't check whether it can also load the halo files", filepath)
             else:
                 h = self._construct_pynbody_halos(f)
 
             return True
-        except (IOError, RuntimeError):
+        except (OSError, RuntimeError):
             return False
 
     def get_timestep_properties(self, ts_extension):
@@ -235,19 +232,18 @@ class PynbodyInputHandler(finding.PatternBasedFileDiscovery, HandlerBase):
 
     def enumerate_objects(self, ts_extension, object_typetag="halo", min_halo_particles=config.min_halo_particles):
         if self._can_enumerate_objects_from_statfile(ts_extension, object_typetag):
-            for X in self._enumerate_objects_from_statfile(ts_extension, object_typetag):
-                yield X
+            yield from self._enumerate_objects_from_statfile(ts_extension, object_typetag)
         else:
-            logger.warn("No halo statistics file found for timestep %r",ts_extension)
+            logger.warning("No halo statistics file found for timestep %r",ts_extension)
 
             snapshot_keep_alive = self.load_timestep(ts_extension)
             try:
                 h = self._construct_halo_cat(ts_extension, object_typetag)
             except:
-                logger.warn("Unable to read %ss using pynbody; assuming step has none", object_typetag)
+                logger.warning("Unable to read %ss using pynbody; assuming step has none", object_typetag)
                 return
 
-            logger.warn(" => enumerating %ss directly using pynbody", object_typetag)
+            logger.warning(" => enumerating %ss directly using pynbody", object_typetag)
 
             istart = 1
 
@@ -302,9 +298,9 @@ class PynbodyInputHandler(finding.PatternBasedFileDiscovery, HandlerBase):
     def _estimate_spatial_resolution_quicker(self, f):
         interparticle_distance = float(f.properties['boxsize'].in_units("kpc a",**f.conversion_context()))/(float(len(f))**(1./3))
         res = 0.01*interparticle_distance
-        logger.warn("Because 'quicker' flag is set, estimating res %.2g kpc from the file size; this could be inaccurate",
+        logger.warning("Because 'quicker' flag is set, estimating res %.2g kpc from the file size; this could be inaccurate",
                     res)
-        logger.warn(" -- it will certainly be wrong for e.g. zoom simulations")
+        logger.warning(" -- it will certainly be wrong for e.g. zoom simulations")
         return res
 
     def _estimate_mass_resolution(self, f):
@@ -318,9 +314,9 @@ class PynbodyInputHandler(finding.PatternBasedFileDiscovery, HandlerBase):
         rho_m = cosmo.rho_M(f, z=0, unit="Msol kpc**-3 a**-3")
         volume_box = float(f.properties['boxsize'].in_units("kpc a",**f.conversion_context()) ** 3)
         estimated_part_mass = rho_m * volume_box / len(f)
-        logger.warn("Because 'quicker' flag is set, estimating mass res %.2g msol from the file size; this could be inaccurate",
+        logger.warning("Because 'quicker' flag is set, estimating mass res %.2g msol from the file size; this could be inaccurate",
                     estimated_part_mass)
-        logger.warn(" -- it will certainly be wrong for e.g. zoom simulations")
+        logger.warning(" -- it will certainly be wrong for e.g. zoom simulations")
         return estimated_part_mass
 
 
@@ -333,7 +329,7 @@ class GadgetSubfindInputHandler(PynbodyInputHandler):
             f = pynbody.load(filepath)
             h = pynbody.halo.SubfindCatalogue(f)
             return True
-        except (IOError, RuntimeError):
+        except (OSError, RuntimeError):
             return False
 
     def load_object(self, ts_extension, finder_id, finder_offset, object_typetag='halo', mode=None):
@@ -341,7 +337,7 @@ class GadgetSubfindInputHandler(PynbodyInputHandler):
             h = self._construct_halo_cat(ts_extension, object_typetag)
             return h.get_halo_properties(finder_offset,with_unit=False)
         else:
-            return super(GadgetSubfindInputHandler, self).load_object(ts_extension, finder_id, finder_offset, object_typetag, mode)
+            return super().load_object(ts_extension, finder_id, finder_offset, object_typetag, mode)
 
     def _construct_group_cat(self, ts_extension):
         f = self.load_timestep(ts_extension)
@@ -355,7 +351,7 @@ class GadgetSubfindInputHandler(PynbodyInputHandler):
 
     def _construct_halo_cat(self, ts_extension, object_typetag):
         if object_typetag== 'halo':
-            return super(GadgetSubfindInputHandler, self)._construct_halo_cat(ts_extension, object_typetag)
+            return super()._construct_halo_cat(ts_extension, object_typetag)
         elif object_typetag== 'group':
             return self._construct_group_cat(ts_extension)
         else:
@@ -435,25 +431,152 @@ class GadgetRockstarInputHandler(PynbodyInputHandler):
             f = pynbody.load(filepath)
             h = pynbody.halo.RockstarCatalogue(f)
             return True
-        except (IOError, RuntimeError):
+        except (OSError, RuntimeError):
             return False
 
+class RamsesCatalogueMixin:
+    def create_bridge(self, f1, f2):
+        import pynbody
 
-class GadgetAHFInputHandler(PynbodyInputHandler):
+        # Ensure that f1.dm and f2.dm are not garbage-collected
+        self._f1dm = f1.dm
+        self._f2dm = f2.dm
+
+        return pynbody.bridge.OrderBridge(self._f1dm, self._f2dm, monotonic=False)
+
+    def match_objects(self, ts1, ts2, halo_min, halo_max, dm_only=True, threshold=0.005,
+                      object_typetag="halo", output_handler_for_ts2=None):
+        import pynbody
+        if not dm_only:
+            logger.warning(
+                "`match_objects` was called with dm_only=%s, but %s only supports DM-only"
+                " catalogues at the moment. Falling back to DM-only.", dm_only, self.__class__.__name__
+            )
+            dm_only = True
+
+        return super().match_objects(
+            ts1,
+            ts2,
+            halo_min,
+            halo_max,
+            dm_only=dm_only,
+            threshold=threshold,
+            object_typetag=object_typetag,
+            output_handler_for_ts2=output_handler_for_ts2,
+            fuzzy_match_kwa={"use_family": pynbody.family.dm}
+        )
+
+
+class AHFInputHandler(PynbodyInputHandler):
+    pynbody_halo_class_name = "AHFCatalogue"
+
+    _included_additional_properties = (
+        "parent", "child", "shrink_center", "bulk_velocity",
+    )
+
+    _excluded_precalculated_properties = (
+        "boxsize", "time", "hostHalo", "Xc", "Yc", "Zc",
+        "VXc", "VYc", "VZc",
+    )
+
+    def available_object_property_names_for_timestep(self, ts_extension, object_typetag):
+        h = self._construct_halo_cat(ts_extension, object_typetag)
+
+        return (
+            [
+                key for key in h[1].properties.keys()
+                if key not in self._excluded_precalculated_properties
+            ] + list(self._included_additional_properties)
+        )
+
+
+    def _get_map_child_subhalos(self, ts_extension):
+        h = self._construct_halo_cat(ts_extension, 'halo')
+        halo_children = defaultdict(list)
+        for halo in h:
+            iparent = halo.properties["hostHalo"] # Returns the unique ID (NOT the halo_id index) of the host
+            if iparent == -1: # If halo is its own host (i.e. -1), move on to next object
+                continue
+
+            halo_children[iparent].append(halo.properties["halo_id"]) # Otherwise store the halo_id index of the host
+        return halo_children
+
+
+    def _get_map_IDs_to_halo_ids(self, ts_extension):
+        # IDs and halo_ids are usually related by ID = halo_id - 1,
+        # but they can be entirely independent when using specific AHF options or running with MPI
+        # This allows to map between one and the other
+        h = self._construct_halo_cat(ts_extension, 'halo')
+        return {
+            halo.properties["ID"]: halo.properties["halo_id"] for halo in h
+        }
+
+    def iterate_object_properties_for_timestep(self, ts_extension, object_typetag, property_names):
+        h = self._construct_halo_cat(ts_extension, object_typetag)
+
+        h.physical_units()
+
+        if "child" in property_names:
+            map_child_parent = self._get_map_child_subhalos(ts_extension)
+
+        if "parent" in property_names:
+            map_ID_to_halo_id = self._get_map_IDs_to_halo_ids(ts_extension)
+
+        for halo in h:
+            # Tangos expect us to yield first the finder offset (index in the pynbody catalogue, halo_id in our case)
+            # and second the finder_id (unique number associated to the halo, ID in our case).
+            all_data = [halo.properties["halo_id"], halo.properties["ID"]]
+
+            halo_props = halo.properties
+            for k in property_names:
+                if k == "parent":
+                    parent_ID = halo_props['hostHalo']
+                    if parent_ID != -1:
+                        # If halo is not its own parent, link to parent
+                        data = proxy_object.IncompleteProxyObjectFromFinderId(
+                            map_ID_to_halo_id[parent_ID],
+                            'halo'
+                        )
+                    else:
+                        # Otherwise link to itself
+                       data = proxy_object.IncompleteProxyObjectFromFinderId(
+                            halo_props['halo_id'],
+                            'halo'
+                        )
+
+
+                elif k == "child":
+                    data = [
+                        proxy_object.IncompleteProxyObjectFromFinderId(ichild, 'halo')
+                        for ichild in map_child_parent[halo_props["ID"]]
+                    ]
+                elif k == "shrink_center":
+                    data = np.array([halo_props[k] for k in ("Xc", "Yc", "Zc")])
+                elif k == "bulk_velocity":
+                    data = np.array([halo_props[k] for k in ("VXc", "VYc", "VZc")])
+                else:
+                    data = halo_props[k]
+                all_data.append(data)
+
+            yield all_data
+
+
+class GadgetAHFInputHandler(AHFInputHandler):
     patterns = ["snapshot_???"]
     auxiliary_file_patterns = ["*.AHF_particlesSTARDUST"]
 
-    def _is_able_to_load(self, filepath):
-        try:
-            f = pynbody.load(filepath)
-            h = pynbody.halo.AHFCatalogue(f)
-            return True
-        except (IOError, RuntimeError):
-            return False
-
-
 
+class RamsesAHFInputHandler(RamsesCatalogueMixin, AHFInputHandler):
+    patterns = ["output_?????"]
+    auxiliary_file_patterns = ["output_?????*z*AHF_halos"]
 
+    _excluded_precalculated_properties = (
+        "boxsize", "time", "hostHalo", "Xc", "Yc", "Zc",
+        "VXc", "VYc", "VZc",
+        "npart","n_gas", "n_star", # will be accessible through NDM()
+        "a", "omegaM0", "omegaL0","h", "fstart", "ovdens", "nbins",
+        "halo_id", "ID" # will be accesisble through finder_id()
+    )
 
 class ChangaInputHandler(PynbodyInputHandler):
     flags_include = ["dPhysDenMin", "dCStar", "dTempMax",
@@ -463,12 +586,12 @@ class ChangaInputHandler(PynbodyInputHandler):
 
 
     def get_properties(self):
-        parent_prop_dict = super(ChangaInputHandler, self).get_properties()
+        parent_prop_dict = super().get_properties()
 
         pfile = self._get_paramfile_path()
 
         if pfile is None:
-            logger.warn("Param file cannot be found - no simulation properties will be available")
+            logger.warning("Param file cannot be found - no simulation properties will be available")
             return {}
         else:
             logger.info("Param file is %s", pfile)
@@ -500,7 +623,7 @@ class ChangaInputHandler(PynbodyInputHandler):
         if os.path.exists(log_path):
             logger.info("Log file is %s", log_path)
         else:
-            logger.warn("Cannot find log file (%s)", log_path)
+            logger.warning("Cannot find log file (%s)", log_path)
             log_path = None
         return log_path, prop_dict
 
@@ -513,7 +636,7 @@ class ChangaInputHandler(PynbodyInputHandler):
 
     def _get_properties_from_log(self, log_path):
         prop_dict = {}
-        with open(log_path, 'r') as f:
+        with open(log_path) as f:
             for l in f:
                 if "# Code compiled:" in l:
                     prop_dict["compiled"] = time.strptime(
@@ -583,4 +706,5 @@ class ChangaUseIDLInputHandler(ChangaInputHandler):
     auxiliary_file_patterns = ["*.amiga.grp"]
 
 from . import caterpillar, eagle, ramsesHOP
+
 RamsesHOPInputHandler = ramsesHOP.RamsesHOPInputHandler
