@@ -2,25 +2,25 @@
 
 For more overview information, see live_calculation.md. """
 
-from __future__ import absolute_import
 import warnings
 
 import numpy as np
-from sqlalchemy.orm import contains_eager, aliased, defaultload
+from sqlalchemy.orm import Load, aliased, contains_eager, defaultload
 
 import tangos.core.dictionary
 import tangos.core.halo
 import tangos.core.halo_data
 from tangos.core import extraction_patterns
 from tangos.live_calculation.query_masking import QueryMask
-from tangos.live_calculation.query_multivalue_folding import QueryMultivalueFolding
+from tangos.live_calculation.query_multivalue_folding import \
+    QueryMultivalueFolding
 from tangos.util import consistent_collection
+
 from .. import core
 from .. import temporary_halolist as thl
-from six.moves import range
-from six.moves import zip
 
-class UnknownValue(object):
+
+class UnknownValue:
     """A dummy object returned by Calculation.proxy_value when the value of the calculation cannot be predicted"""
     def __init__(self, name=None):
         self.name = name
@@ -28,7 +28,7 @@ class UnknownValue(object):
 class NoResultsError(ValueError):
     pass
 
-class Calculation(object):
+class Calculation:
     """Represents a live-calculation to be performed on database objects.
 
     A typical Calculation is composed of many different Calculation subclasses arranged in some form of tree.
@@ -104,7 +104,7 @@ class Calculation(object):
                 self._r_dict_ids_essential_cached = set()
                 retrieves = self.retrieves()
                 try:
-                    self._n_join_levels = max([r.count('.') for r in retrieves])+1
+                    self._n_join_levels = max(r.count('.') for r in retrieves)+1
                 except ValueError:
                     self._n_join_levels = 0
                 for r in retrieves:
@@ -219,22 +219,22 @@ class Calculation(object):
         The return from values_sanitized has shape n_columns() x n_halos"""
         return 1
 
-    def supplement_halo_query(self, halo_query):
-        """Return a sqlalchemy query with a supplemental join to allow this calculation to run efficiently"""
+    def supplement_halo_query(self, halo_query, halo_alias=None):
+        """Return a sqlalchemy query with a supplemental join to allow this calculation to run efficiently
+
+        halo_query: The query that returns the simulation objects on which calculations are going to be made
+        halo_alias: The alias for the simulation object class being referenced (or None to use SimulationObjectBase)"""
         name_targets = self.retrieves_dict_ids()
-        halo_alias = tangos.core.halo.SimulationObjectBase
+        if halo_alias is None:
+            halo_alias = tangos.core.halo.SimulationObjectBase
         augmented_query = halo_query
         order_bys = []
+        current_join_path = None
+
         for i in range(self.n_join_levels()):
             halo_property_alias = aliased(tangos.core.halo_data.HaloProperty)
             halo_link_alias = aliased(tangos.core.halo_data.HaloLink)
 
-            path_to_properties = [tangos.core.halo.SimulationObjectBase.all_links, tangos.core.halo_data.HaloLink.halo_to] * i + [
-                tangos.core.halo.SimulationObjectBase.all_properties]
-            path_to_links = [tangos.core.halo.SimulationObjectBase.all_links, tangos.core.halo_data.HaloLink.halo_to] * i + [
-                tangos.core.halo.SimulationObjectBase.all_links]
-
-
             if len(name_targets)>0:
                 property_name_condition = halo_property_alias.name_id.in_(name_targets)
                 link_name_condition = (halo_link_alias.relation_id.in_(name_targets))
@@ -252,19 +252,21 @@ class Calculation(object):
                                                   & property_name_condition).\
                                         outerjoin(halo_link_alias,
                                                   (halo_alias.id==halo_link_alias.halo_from_id)
-                                                  & link_name_condition).\
-                                        options(contains_eager(*path_to_properties, alias=halo_property_alias),
-                                                contains_eager(*path_to_links, alias=halo_link_alias),
-                                                defaultload(*path_to_properties).undefer_group("data"))
+                                                  & link_name_condition)
+            augmented_query = augmented_query.options(
+                Load(halo_alias).contains_eager(halo_alias.all_properties, alias=halo_property_alias).undefer("*"),
+                Load(halo_alias).contains_eager(halo_alias.all_links, alias=halo_link_alias),
+            )
 
             order_bys+=[halo_link_alias.id,halo_property_alias.id]
 
             if i<self.n_join_levels()-1:
                 next_level_halo_alias = aliased(tangos.core.halo.SimulationObjectBase)
-                path_to_new_halo = path_to_links + [tangos.core.halo_data.HaloLink.halo_to]
                 augmented_query = augmented_query.outerjoin(next_level_halo_alias,
                                                             (halo_link_alias.halo_to_id==next_level_halo_alias.id)).\
-                                        options(contains_eager(*path_to_new_halo, alias=next_level_halo_alias))
+                                                  options(Load(halo_link_alias).\
+                                                          contains_eager(halo_link_alias.halo_to, alias=next_level_halo_alias)
+                                                          )
 
                 halo_alias = next_level_halo_alias
         augmented_query = augmented_query.order_by(*order_bys)
@@ -289,7 +291,7 @@ class Calculation(object):
 class MultiCalculation(Calculation):
     """Represents a single calculation that returns the results from multiple sub-calculations."""
     def __init__(self, *calculations):
-        super(MultiCalculation, self).__init__()
+        super().__init__()
         self.calculations = [c if isinstance(c, Calculation) else parser.parse_property_name(c) for c in calculations]
 
     def retrieves(self):
@@ -325,7 +327,7 @@ class MultiCalculation(Calculation):
 class FixedInput(Calculation):
     """Represents a calculation that returns a fixed value"""
     def __init__(self, *tokens):
-        super(FixedInput, self).__init__()
+        super().__init__()
         self.value = str(tokens[0])
 
     def __str__(self):
@@ -343,7 +345,7 @@ class FixedInput(Calculation):
 class FixedNumericInput(FixedInput):
     """Represents a calculation that returns a fixed numerical value"""
     def __init__(self, *tokens):
-        super(FixedNumericInput, self).__init__()
+        super().__init__()
 
     @staticmethod
     def _process_numerical_value(t):
@@ -368,7 +370,7 @@ class LiveProperty(Calculation):
 
 
     def __init__(self, *tokens):
-        super(LiveProperty, self).__init__()
+        super().__init__()
         self._name = str(tokens[0])
         self._inputs = list(tokens[1:])
 
@@ -496,7 +498,7 @@ class BuiltinFunction(LiveProperty):
         return func_name in list(cls.__registered_functions.keys())
 
     def __init__(self, *tokens):
-        super(BuiltinFunction, self).__init__(*tokens)
+        super().__init__(*tokens)
         self._func = self.__registered_functions[self._name]['function']
         self._info = self.__registered_functions[self._name]
         for i in range(len(self._inputs)):
@@ -520,7 +522,7 @@ class BuiltinFunction(LiveProperty):
         if self._get_input_option(input_id, 'provide_proxy'):
             return self._inputs[input_id].proxy_value(), None
         else:
-            return super(BuiltinFunction, self)._input_value_and_description(input_id, halos)
+            return super()._input_value_and_description(input_id, halos)
 
     def _calculation_retrieves(self):
         return set()
@@ -537,7 +539,7 @@ class BuiltinFunction(LiveProperty):
 class Link(Calculation):
     """Represents a calculation to be made on a halo linked to the input in some way"""
     def __init__(self, *tokens):
-        super(Link, self).__init__()
+        super().__init__()
         self.locator = tokens[0]
         self.property = tokens[1]
         self._multi_selection_basis = 'first'
@@ -665,7 +667,7 @@ class StoredProperty(Calculation):
     """Represents a named property with value stored in the database"""
 
     def __init__(self, *tokens):
-        super(StoredProperty,self).__init__()
+        super().__init__()
         self._name = tokens[0]
         self._multivalued = False
 
@@ -723,5 +725,4 @@ class StoredProperty(Calculation):
 
 
 
-from . import parser
-from . import builtin_functions
+from . import builtin_functions, parser
