@@ -1,7 +1,6 @@
-from __future__ import absolute_import
-import logging
-from six import StringIO
 import copy
+import logging
+from io import StringIO
 
 logger = logging.getLogger(__name__)
 
@@ -13,7 +12,7 @@ handler_stderr.setFormatter(formatter)
 logger.addHandler(handler_stderr)
 
 
-class LogCapturer(object):
+class LogCapturer:
     def __init__(self):
         self.buffer = StringIO()
         self.handler_buffer = logging.StreamHandler(self.buffer)
@@ -39,4 +38,4 @@ class LogCapturer(object):
 def set_identity_string(identifier):
     global handler_stderr
     formatter = logging.Formatter(identifier+"%(asctime)s : %(message)s")
-    handler_stderr.setFormatter(formatter)
\ No newline at end of file
+    handler_stderr.setFormatter(formatter)
