@@ -1,16 +1,14 @@
-from __future__ import absolute_import, print_function
-import numpy as np
-from tangos.util import timing_monitor
-import six
-from six.moves import zip
+import functools
 import importlib
 import warnings
-import functools
-from .. import input_handlers
-from .. import util
-from .. import parallel_tasks
+
+import numpy as np
 import pkg_resources
 
+from tangos.util import timing_monitor
+
+from .. import input_handlers, parallel_tasks
+
 
 class PropertyCalculationMetaClass(type):
     # Present to register new subclasses of PropertyCalculation, so that subclasses can be dynamically
@@ -19,15 +17,17 @@ class PropertyCalculationMetaClass(type):
     def __init__(cls, name, bases, dict):
         type.__init__(cls, name, bases, dict)
         if hasattr(cls, 'name'):
-            warnings.warn("%r defines a name() class method which is deprecated. Use instead a class static variable 'names'."%cls, DeprecationWarning)
+            warnings.warn("%r defines a name() class method which is deprecated. "
+                          "Use instead a class static variable 'names'."%cls, DeprecationWarning, stacklevel=2)
             cls.names = cls.name()
         if callable(cls.requires_particle_data):
-            warnings.warn("%r defines a requires_particle_data() class method which is deprecated; it should instead be a class static variable", DeprecationWarning)
+            warnings.warn("%r defines a requires_particle_data() class method which is deprecated; "
+                          "it should instead be a class static variable", DeprecationWarning, stacklevel=2)
             cls.requires_particle_data = cls.requires_particle_data()
         if cls.names is not None:
             cls._all_classes.append(cls)
 
-class PropertyCalculation(six.with_metaclass(PropertyCalculationMetaClass,object)):
+class PropertyCalculation(metaclass=PropertyCalculationMetaClass):
     _all_classes = []
 
     # In child class, defines the most general handler that this property is compatible with.
@@ -176,7 +176,7 @@ class PropertyCalculation(six.with_metaclass(PropertyCalculationMetaClass,object
         """
         values = self.live_calculate(halo_entry, *input_values)
         names = self.names
-        if isinstance(names, six.string_types):
+        if isinstance(names, str):
             return values
         else:
             return values[self.names.index(name)]
@@ -265,7 +265,7 @@ class TimeChunkedProperty(PropertyCalculation):
 
     def __init__(self, simulation):
         self.pixel_delta_t_Gyr = simulation.get("histogram_delta_t_Gyr", self.pixel_delta_t_Gyr)
-        super(TimeChunkedProperty, self).__init__(simulation)
+        super().__init__(simulation)
 
 
     def bin_index(self, time):
@@ -356,7 +356,7 @@ class LivePropertyCalculation(PropertyCalculation):
     requires_particle_data = False
 
     def __init__(self, simulation, *args):
-        super(LivePropertyCalculation, self).__init__(simulation)
+        super().__init__(simulation)
         self._nargs = len(args)
 
     def calculate(self, _, halo):
@@ -373,7 +373,7 @@ class LivePropertyCalculationInheritingMetaProperties(LivePropertyCalculation):
         :param inherits_from: The PropertyCalculation description from which the metadata should be inherited
         :type inherits_from: PropertyCalculation
         """
-        super(LivePropertyCalculationInheritingMetaProperties, self).__init__(simulation)
+        super().__init__(simulation)
         self._inherits_from = inherits_from(simulation)
 
     def plot_x0(self):
@@ -407,7 +407,7 @@ def all_properties(with_particle_data=True):
             continue
 
         name = c.names
-        if isinstance(name, six.string_types):
+        if isinstance(name, str):
             _check_class_provided_name(name)
             pr.append(name)
         else:
@@ -417,7 +417,7 @@ def all_properties(with_particle_data=True):
 
     return pr
 
-@util.lru_cache()
+@functools.lru_cache()
 def providing_class(property_name, handler_class=None, silent_fail=False):
     """Return property calculator class for given property name when files will be loaded by specified handler.
 
@@ -439,7 +439,7 @@ def providing_class(property_name, handler_class=None, silent_fail=False):
     else:
         raise NameError("No providing class for property " + property_name)
 
-@util.lru_cache()
+@functools.lru_cache()
 def all_providing_classes(property_name):
     """Return all the calculator classes for the given property name (possibly multiple, for different handlers)"""
     classes = all_property_classes()
