@@ -1,11 +1,12 @@
-from __future__ import absolute_import
-from __future__ import print_function
-import tangos.core.halo
-from tangos.input_handlers.changa_bh import ShortenedOrbitLog, BlackHolesLog
-from . import PynbodyPropertyCalculation
-from .. import LivePropertyCalculation, TimeChunkedProperty
 import numpy as np
-import scipy, scipy.interpolate
+import scipy
+import scipy.interpolate
+
+import tangos.core.halo
+from tangos.input_handlers.changa_bh import BlackHolesLog, ShortenedOrbitLog
+
+from .. import LivePropertyCalculation, TimeChunkedProperty
+from . import PynbodyPropertyCalculation
 
 
 class BH(PynbodyPropertyCalculation):
@@ -32,7 +33,7 @@ class BH(PynbodyPropertyCalculation):
         print(self.log)
 
     def calculate(self, halo, properties):
-        if not isinstance(properties, tangos.core.halo.Halo):
+        if not isinstance(properties, tangos.core.halo.BH):
             raise RuntimeError("No proxies, please")
         boxsize = self.log.boxsize
 
@@ -84,10 +85,7 @@ class BH(PynbodyPropertyCalculation):
 class BHAccHistogram(TimeChunkedProperty):
 
     requires_particle_data = True
-
-    @classmethod
-    def name(self):
-        return "BH_mdot_histogram"
+    names = "BH_mdot_histogram",
 
     def requires_property(self):
         return []
@@ -136,7 +134,7 @@ class BHAccHistogram(TimeChunkedProperty):
 
         Mdot_grid = scipy.interpolate.interp1d(t_orbit[order], Mdot_orbit[order], bounds_error=False)(t_grid)
 
-        return Mdot_grid[self.store_slice(t_max)]
+        return Mdot_grid[self.store_slice(t_max)],
 
 
 class BHAccHistogramMerged(PynbodyPropertyCalculation):
@@ -172,7 +170,7 @@ class BHAccHistogramMerged(PynbodyPropertyCalculation):
 
 class BHGal(LivePropertyCalculation):
     def __init__(self, simulation=None, choose='BH_mass', minmax='max', bhtype='BH_central'):
-        super(BHGal, self).__init__(simulation)
+        super().__init__(simulation)
         self._maxmin = minmax
         self._choicep = choose
         self._bhtype = bhtype
@@ -208,4 +206,4 @@ class BHCentral(BHGal):
     names = 'bhcenter'
 
     def __init__(self, simulation=None):
-        super(BHCentral, self).__init__(simulation, 'BH_central_distance', 'min', 'BH_central')
+        super().__init__(simulation, 'BH_central_distance', 'min', 'BH_central')
