@@ -1,5 +1,6 @@
-from .. import PropertyCalculation
 from ...input_handlers import pynbody as pynbody_handler_module
+from .. import PropertyCalculation
+
 
 class PynbodyPropertyCalculation(PropertyCalculation):
     works_with_handler = pynbody_handler_module.PynbodyInputHandler
@@ -7,4 +8,4 @@ class PynbodyPropertyCalculation(PropertyCalculation):
 
 PynbodyHaloProperties = PynbodyPropertyCalculation # old name, to be deprecated
 
-from . import BH, SF, zoom, centring, profile, images, gas, eagle, mass
\ No newline at end of file
+from . import BH, SF, centring, eagle, gas, images, mass, profile, zoom
