@@ -1,6 +1,6 @@
-from __future__ import absolute_import
 from . import PynbodyPropertyCalculation
 
+
 class SphericalRegionPropertyCalculation(PynbodyPropertyCalculation):
     """A base class for calculations which require all data within a sphere (rather than just the literal
     halo finder output)"""
@@ -10,6 +10,6 @@ class SphericalRegionPropertyCalculation(PynbodyPropertyCalculation):
         return pynbody.filt.Sphere(db_data['max_radius'], db_data['shrink_center'])
 
     def requires_property(self):
-        return ["shrink_center", "max_radius"]+super(SphericalRegionPropertyCalculation, self).requires_property()
+        return ["shrink_center", "max_radius"]+super().requires_property()
 
-SphericalRegionHaloProperties = SphericalRegionPropertyCalculation # old name, to be deprecated
\ No newline at end of file
+SphericalRegionHaloProperties = SphericalRegionPropertyCalculation # old name, to be deprecated
