@@ -1,13 +1,14 @@
-from __future__ import absolute_import
 import sqlalchemy
 import sqlalchemy.exc
 import sqlalchemy.orm
 import sqlalchemy.orm.dynamic
 import sqlalchemy.orm.query
 from sqlalchemy.orm import Session, contains_eager
+
 from .. import core, temporary_halolist
 
-class HopStrategy(object):
+
+class HopStrategy:
     """HopStrategy and its descendants define methods helpful for finding related halos, e.g. progenitors/descendants,
     or corresponding halos in other simulation runs"""
 
@@ -26,13 +27,13 @@ class HopStrategy(object):
         if ts is None:
             query = query.filter(0 == 1)
         else:
-            query = query.join("halo_to").filter(core.halo.SimulationObjectBase.timestep_id == ts.id)
+            query = query.join(self._link_orm_class.halo_to).filter(core.halo.SimulationObjectBase.timestep_id == ts.id)
 
         return query
 
     def _target_simulation(self, query, sim):
         """Only return those hops which reach the specified simulation"""
-        query = query.join("halo_to", "timestep").filter(
+        query = query.join(self._link_orm_class.halo_to).join(core.SimulationObjectBase.timestep).filter(
             core.timestep.TimeStep.simulation_id == sim.id)
 
         return query
@@ -147,10 +148,13 @@ class HopStrategy(object):
         halo_alias = None
         if self._ordering_requires_join():
             timestep_alias = sqlalchemy.orm.aliased(core.timestep.TimeStep)
-            halo_alias = sqlalchemy.orm.aliased(core.halo.Halo)
-            query = query.join(halo_alias, self._link_orm_class.halo_to_id == halo_alias.id).join(timestep_alias)
-            query = query.options(contains_eager("halo_to", alias=halo_alias))
-            query = query.options(contains_eager("halo_to", "timestep", alias=timestep_alias))
+            halo_alias = sqlalchemy.orm.aliased(core.halo.SimulationObjectBase)
+            query = query.join(halo_alias, self._link_orm_class.halo_to_id == halo_alias.id)\
+                .join(timestep_alias)\
+                .options(
+                  contains_eager(self._link_orm_class.halo_to.of_type(halo_alias))\
+                  .contains_eager(halo_alias.timestep.of_type(timestep_alias))
+            )
         query = query.order_by(*self._order_by_clause(halo_alias, timestep_alias))
         return query
 
@@ -160,7 +164,7 @@ class HopMajorDescendantStrategy(HopStrategy):
     def __init__(self, halo_from):
         target_ts = halo_from.timestep.next
         if target_ts:
-            super(HopMajorDescendantStrategy, self).__init__(halo_from, target=target_ts)
+            super().__init__(halo_from, target=target_ts)
         else:
             self._all = []
 
@@ -171,6 +175,6 @@ class HopMajorProgenitorStrategy(HopStrategy):
     def __init__(self, halo_from):
         target_ts = halo_from.timestep.previous
         if target_ts:
-            super(HopMajorProgenitorStrategy, self).__init__(halo_from, target=target_ts)
+            super().__init__(halo_from, target=target_ts)
         else:
-            self._all = []
\ No newline at end of file
+            self._all = []
