@@ -1,9 +1,15 @@
 #!/usr/bin/env python2.7
 
-from __future__ import absolute_import
-from __future__ import print_function
+import argparse
+import gc
+import glob
+import sys
+
+import numpy as np
+import pynbody
+from sqlalchemy.orm import Session
+
 import tangos as db
-from tangos.util.check_deleted import check_deleted
 import tangos.core.dictionary
 import tangos.core.halo
 import tangos.core.halo_data
@@ -12,17 +18,10 @@ import tangos.core.tracking
 import tangos.parallel_tasks as parallel_tasks
 import tangos.parallel_tasks.database
 import tangos.tracking
-from tangos.input_handlers.changa_bh import ShortenedOrbitLog, BlackHolesLog
-from sqlalchemy.orm import Session
+from tangos.input_handlers.changa_bh import BlackHolesLog, ShortenedOrbitLog
 from tangos.log import logger
-import sys
-import numpy as np
-import gc
-import argparse
-import glob
-import pynbody
-import six
-from six.moves import zip
+from tangos.util.check_deleted import check_deleted
+
 
 def get_parser_object():
     parser = argparse.ArgumentParser()
@@ -159,10 +158,10 @@ def assign_bh_to_halos(bh_halo_assignment, bh_iord, timestep, linkname, hostname
             haloi = int(haloi)
             bhi = int(bhi)
             if haloi not in halo_catind:
-                logger.warn("Skipping BH in halo %d as no corresponding halo found in the database", haloi)
+                logger.warning("Skipping BH in halo %d as no corresponding halo found in the database", haloi)
                 continue
             if bhi not in existing_bh_nums:
-                logger.warn("Can't find the database object for BH %d", bhi)
+                logger.warning("Can't find the database object for BH %d", bhi)
                 print(bhi)
                 print(existing_bh_nums)
                 continue
@@ -207,7 +206,7 @@ def add_missing_trackdata_and_BH_objects(timestep, this_step_bh_iords, existing_
 
 
 def resolve_multiple_mergers(bh_map):
-    for k,v in six.iteritems(bh_map):
+    for k,v in bh_map.items():
         if v[0] in bh_map:
             old_target = v[0]
             old_weight = v[1]
@@ -283,9 +282,9 @@ def generate_halolinks(session, fname, pairs):
         resolve_multiple_mergers(bh_map)
         logger.info("Gathering BH merger links for steps %r and %r", ts1, ts2)
         with session.no_autoflush:
-            for src,(dest,ratio) in six.iteritems(bh_map):
+            for src,(dest,ratio) in bh_map.items():
                 if src not in nums1 or dest not in nums2:
-                    logger.warn("Can't link BH %r -> %r; missing BH objects in database",src,dest)
+                    logger.warning("Can't link BH %r -> %r; missing BH objects in database",src,dest)
                     continue
                 bh_src_before = bh_objects_1[nums1.index(src)]
                 bh_dest_after = bh_objects_2[nums2.index(dest)]
@@ -344,7 +343,3 @@ def run():
 
 def main():
     parallel_tasks.launch(run)
-
-
-
-
