@@ -1,12 +1,11 @@
 #!/usr/bin/env python
 
-from __future__ import absolute_import
-from __future__ import print_function
 
 import sys
 
+
 def run_importer(argv):
-    from tangos import parallel_tasks, core
+    from tangos import core, parallel_tasks
     from tangos.tools.property_importer import PropertyImporter
     importer = PropertyImporter()
     importer.parse_command_line(argv)
@@ -18,4 +17,3 @@ def main():
        'tangos_import_from_ahf' may be removed in future versions.
        """)
     run_importer(sys.argv[1:])
-
