@@ -1,12 +1,11 @@
 #!/usr/bin/env python2.7
 
 
-from __future__ import absolute_import
-from tangos import core
-from tangos import parallel_tasks
+import sys
+
+from tangos import core, parallel_tasks
 from tangos.parallel_tasks import database
 from tangos.tools.crosslink import TimeLinker
-import sys
 
 
 def run_dbwriter(argv):
@@ -21,4 +20,3 @@ def main():
     'tangos_timelink' may be removed in future versions.
     """)
     parallel_tasks.launch(run_dbwriter, 2, [sys.argv[1:]])
-
