@@ -1,4 +1,4 @@
-class ConsistentCollection(object):
+class ConsistentCollection:
     """Access attributes of an underlying collection of objects, ensuring they are consistent.
 
     This class wraps a list of objects and, when getting attributes or values, behaves transparently as though it is
@@ -28,4 +28,4 @@ class ConsistentCollection(object):
         return values[0]
 
 def consistent_simulation_from_halos(halos):
-    return ConsistentCollection([x.timestep.simulation for x in halos])
\ No newline at end of file
+    return ConsistentCollection([x.timestep.simulation for x in halos])
