@@ -1,7 +1,8 @@
 import socket
-from six.moves.urllib import parse
+from urllib import parse
 
-class BreadCrumbs(object):
+
+class BreadCrumbs:
     def __init__(self, uri=None, servername="TANGOS"):
         if uri:
             self.uri = uri  # invoke uri.setter
@@ -40,5 +41,5 @@ class BreadCrumbs(object):
         return links
 
 def breadcrumbs(request):
-    c = BreadCrumbs(request.url, servername="TANGOS on "+socket.gethostname())
-    return " &rarr; ".join(c.links)
\ No newline at end of file
+    c = BreadCrumbs(request.url, servername="tangos on "+socket.gethostname())
+    return " &rarr; ".join(c.links)
